@@ -10,7 +10,7 @@ import Github.Data
 import Github.Private
 
 import Data.ByteString.Char8 (pack)
-import qualified Network.HTTP.Conduit as C (statusCode)
+import qualified Network.HTTP.Conduit as C (responseStatus)
 import qualified Network.HTTP.Types as T (statusCode)
 
 -- | All the users who have collaborated on a repo.
@@ -27,9 +27,10 @@ collaboratorsOn userName repoName =
 -- > isCollaboratorOn "johnson" "thoughtbot" "paperclip"
 isCollaboratorOn :: String -> String -> String -> IO (Either Error Bool)
 isCollaboratorOn userName repoOwnerName repoName = do
-  result <- doHttps (pack "GET")
-                    (buildUrl ["repos", repoOwnerName, repoName, "collaborators", userName])
-                    Nothing
-  return $ either (Left . HTTPConnectionError)
-                  (Right . (204 ==) . T.statusCode . C.statusCode)
-                  result
+   result <- doHttps (pack "GET")
+                     (buildUrl ["repos", repoOwnerName, repoName, "collaborators", userName])
+                     Nothing
+                     Nothing
+   return $ either (Left . HTTPConnectionError)
+                   (Right . (204 ==) . T.statusCode . C.responseStatus)
+                   result
